function [sumRmtx]=aggrev_fn(MTX,obs,hs,ti)
%Function AGGREV
%Purpose:   Computes revenues using data on P and Q for I products over T 
%           periods. Can handle missing observations
%Format:    [sumRmtx]=pinx_fn(MTX,obs,hs,ti)
%Input:     MTX     IxJ matrix, where 
%                   I   number of products 
%                   J   structured as [hs(headsize)+T(Q)+T(P)]. Hence MTX
%                   includes sequentially (i)product charateristics, (ii) 
%                   data on Q and (iii) data on P
%           obs     Number of monthly observations
%           hs      Number of columns with product characteristics that
%                   preceed data on Q and P
%           ti      time intervat (1=m,3=q,12=y)
%Output:    sumRmtx 1xT vector of aggregate revenues
%   Rudolfs Bems, Oct 2012

T=floor(obs/ti);
sumRmtx=nan(1,T);

% proceed to compute only if there is data
if ~isempty(MTX)==1
    
    I=size(MTX,1);
    P=MTX(:,hs+obs+1:hs+2*obs);
    Q=MTX(:,hs+1:hs+obs);
    Rmtx=Q.*P;
    
    %check if there is any data
    if sum(sum(isnan(P)))==numel(P);disp('nodata');return;end
    if sum(sum(isnan(Q)))==numel(P);disp('nodata');return;end
    
    %aggregate revs, Qs and Ps to relevant time interval (ti)
    tempR=nan(I,T);
    for t=1:T
        tempR(:,t)=nansum(Rmtx(:,(t-1)*ti+1:t*ti),2)./...
            max(~isnan(Rmtx(:,(t-1)*ti+1:t*ti)),[],2);
        %"max" is a trick to get nansum(NaN)/max(~isnan(NaN))=0/0=NaN,
        %instead of nansum(NaN)=0
    end
    sumRmtx=nansum(tempR,1)./max(~isnan(tempR),[],1);%"max" trick
end