%Prepares a more limited dataset where everything is expressed in unit
%values and quanitites (uniform in a group). To do this we drop:
%   (i)   items with units 3 or 4
%   (ii)  items with no units
%   (iii) items with weight 0
%   (iv)  items with a 4-digit product group that are not in most frequent 
%         units
% This code also aggregates monthly to quarterly frequency
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
% load ../Data/dataAER_RR allLVAdata_dropIN
% MTX=allLVAdata_dropIN;
load ../Data/dataAER_RR allLVAdata_DONOTdropIN
MTX=allLVAdata_DONOTdropIN;

%choose sectoral detail
sec_level=4;

%aggregate MTX into quarterly data
ti=3;
hs=9;
obs=(size(MTX,2)-hs)/2;
I=size(MTX,1);
T=floor(obs/ti);
P=MTX(:,hs+obs+1:hs+2*obs);
Q=MTX(:,hs+1:hs+obs);
Rmtx=P.*Q;
R_ALL=nansum(Rmtx,1)';
tempQ=nan(I,T);
tempR=nan(I,T);
for t=1:T
    tempQ(:,t)=nansum(Q(:,(t-1)*ti+1:t*ti),2)./...
        max(~isnan(Q(:,(t-1)*ti+1:t*ti)),[],2);
    tempR(:,t)=nansum(Rmtx(:,(t-1)*ti+1:t*ti),2)./...
        max(~isnan(Rmtx(:,(t-1)*ti+1:t*ti)),[],2);
    %"max" is a trick to get nansum(NaN)/max(~isnan(NaN))=0/0=NaN,
    %instead of nansum(NaN)=0
end
R_ALL=nansum(tempR,1)';
P=tempR./tempQ;
MTX=[MTX(:,1:hs) tempQ P];%output: quarterly scanner data
Revenues_1=nansum(R_ALL);

%Drop if units==3 or 4 or NaN
MTX_no3=MTX(~ismember(MTX(:,6),[3 4]),:);
MTX_no3=MTX_no3(~isnan(MTX_no3(:,6)),:);

%Drop if net weight is ==0
MTX_no3=MTX_no3(MTX_no3(:,7)>0,:);

%crate a new MTX with (i) prices in UV and (ii) Q in units for each 'g'
MTX_new=[];
for prodlev=sec_level%0:4 %Choose product level
    
    list=floor(1000/(10^(4-prodlev))):floor(9999/(10^(4-prodlev)));
    
    for ProdDef=list%list of feasible sectors
        
        %restrict MTX to the particular product
        MCtree_X=ProdDef*(10^(4-prodlev)):...
            ProdDef*(10^(4-prodlev))+floor(0.9999*(10^(4-prodlev)));
        
        %prepare data for the product group of interest
        MTX2=MTX_no3(ismember(MTX_no3(:,2),MCtree_X),:);
        units=MTX2(:,6);%vector of units used by the group
        MTX2=MTX2(MTX2(:,6)==mode(units),:);%keep only most frequent units
        
        if ~isempty(MTX2)==1%proceed only if MTX not empty
            ntwgt=MTX2(:,7);%vector of product weights
            Q=MTX2(:,hs+1:hs+T);
            P=MTX2(:,hs+T+1:hs+2*T);
            head=MTX2(:,1:hs);
            Rmtx=P.*Q;
            P_new=P./repmat(ntwgt,1,T);%price per unit for each item
            Q_new=Q.*repmat(ntwgt,1,T);%units sold
            
            %colect relevant data
            MTX_new=[MTX_new;[head Q_new P_new]];
        end
    end
end
%How much data is lost?
Qtmp=MTX_no3(:,hs+1:hs+T);
Ptmp=MTX_no3(:,hs+T+1:hs+2*T);
Revenues_2=nansum(nansum(Ptmp.*Qtmp));
Qtmp=MTX_new(:,hs+1:hs+T);
Ptmp=MTX_new(:,hs+T+1:hs+2*T);
Revenues_3=nansum(nansum(Ptmp.*Qtmp));
R_ALL=nansum(Ptmp.*Qtmp,1);
[Revenues_2/Revenues_1 Revenues_3/Revenues_1] %after step1, step2
%NOTES 
% 4-dig groups: 10% of revenues dropped, mostly because of step 1.

% allLVAdata_dropIN_4secUV=MTX_new;
% save ../Data/dataAER_RR allLVAdata_dropIN_4secUV -append
allLVAdata_DONOTdropIN_4secUV=MTX_new;
save ../Data/dataAER_RR allLVAdata_DONOTdropIN_4secUV -append