%computes CPI and Q dynamics by country of origin and product group
clear all
load ../Data/dataAER_RR
%MTX=allLVAdata_dropIN;
MTX=allLVAdata_dropIN_4secUV;  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%User inputs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%time interval (12=annual;3=quarterly;1=monthly)
ti=1; %from quarterly data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%define matrix that compile results
hs=9;
obs=(size(MTX,2)-hs)/2;
DATAMTX=[];
DATAMTXsum=[];

for prodlev=0:4
    for store=[0 1 2 3]
        disp([prodlev store])
        %filter by store type
        if store~=0
            MTX2=MTX(MTX(:,1)==store,:);
        else
            MTX2=MTX;
        end
        
        %total revenes after store and CPI filters
        ALLR=aggrev_fn(MTX2,obs,hs,ti);
        
        %define "feasible" product list for each product level (i.e.:1,2,3,4,)
        list=floor(1000/(10^(4-prodlev))):floor(9999/(10^(4-prodlev)));
        
        %compute data of interest for each product category (agg. and by origin)
        for ProdDef=list
            
            %restrict MTX to the particular product, conditional on product level
            MCtree_X=ProdDef*(10^(4-prodlev)):...
                ProdDef*(10^(4-prodlev))+floor(0.9999*(10^(4-prodlev)));
            MTXtemp=MTX2(ismember(MTX2(:,2),MCtree_X),:);%subset of goods only
            
            if ~isempty(MTXtemp)==1%proceed only if MTX not empty. This 
                %only used to get rid of 4-digit codes that MCtree_X
                %generates, but that do not really exist.
                
                %revs, Q and P for the product
                [sumRmtx,totinum,totminovlp,dtotQ_C,dpG,dpF]=pinx_fn(MTXtemp,obs,hs,ti);
                FBshare=sumRmtx./ALLR*100;
                
                %define country groups
                ind_LV=find(ismember(MTXtemp(:,9),[101 941]));
                ind_OT=find(~ismember(1:size(MTXtemp,1),ind_LV)');
                check=length([ind_LV;ind_OT])/size(MTXtemp,1);
                if check~=1; disp(':-1'); end; clear check
                ind_str=['LV';'OT'];
                
                %revs, Q and P for the good by country
                rev_C=nan(length(ind_str),floor(obs/ti));
                inum_C=nan(length(ind_str),floor(obs/ti));
                minovlp_C=nan(length(ind_str),floor(obs/ti));
                dCPI_C=nan(length(ind_str),floor(obs/ti)-1);
                dCPI_C_F=nan(length(ind_str),floor(obs/ti)-1);
                dQ_C=nan(length(ind_str),floor(obs/ti)-1);
                if sum(sum(isnan(sumRmtx)))<numel(sumRmtx)%only if there is any data
                    for k=1:length(ind_str)
                        ind=eval(['ind_' ind_str(k,:)]);
                        [rev_C(k,:),inum_C(k,:),minovlp_C(k,:),dQ_C(k,:),dCPI_C(k,:),dCPI_C_F(k,:)]=...
                            pinx_fn(MTXtemp(ind,:),obs,hs,ti);
                        ObsNum_C(k)=size(MTXtemp(ind,:),1);
                    end
                    revshr=rev_C./(ones(length(ind_str),1)*nansum(rev_C));
                    if abs(nansum(revshr)-1)>1e-8; disp(':-2');end;
                end
                
                %define inputs for the data matrix  
                TimeVec=[1:floor(obs/ti)]';
                ProdCode=repmat(ProdDef,floor(obs/ti),1);
                StreCode=repmat(store,floor(obs/ti),1);
                P=log([nan;dpG']);
                Q=log([nan;dtotQ_C']);
                R=sumRmtx'./1e+6;
                S=FBshare';
                Porig=log([nan(1,length(ind_str));dCPI_C']);
                Qorig=log([nan(1,length(ind_str));dQ_C']);
                Rorig=rev_C'./1e+6;
                Sorig=revshr'.*100;
                inumorig=inum_C';
                ovlporig=minovlp_C';
                PF=log([nan;dpF']);
                PForig=log([nan(1,length(ind_str));dCPI_C_F']);
                
                %compile data matrix
                temp=[TimeVec ProdCode StreCode P Q R S...
                    Porig Qorig Rorig Sorig inumorig ovlporig PF PForig];
                DATAMTX=[DATAMTX;temp];
                                
                %compile summary data matrix
                temp2=[ProdCode(1) StreCode(1) nansum(R)/(nansum(ALLR)./1e+6)*100 ...
                    nansum(Rorig,1)./(ones(1,length(ind_str)).*sum(nansum(Rorig,1)))*100 ...
                    sum(ObsNum_C) ObsNum_C...
                    min(inumorig,[],1) min(ovlporig,[],1)];
                DATAMTXsum=[DATAMTXsum;temp2];
            end
        end
    end
end

%save ../Data/PandQdata DATAMTX DATAMTXsum
%save ../Data/PandQdata_4secUV DATAMTX DATAMTXsum