set more off
set matsize 10000


/*
	Date: September 2016

	Paper: "Income-Induced Expenditure Switching," Bems and di Giovanni (2016)

	Calcultes entry, exit and continuers to plot in Matlab for Figure A1
	
	Program: 
	
		1. Loads in super market data
		2. Generates entry, exit, continue for each item:
			a) Count
			b) Value
		3. Collapses by domestic and foreign each period
	
*/

foreach D of numlist 4{
	use 4julian_`D'digit_Xi1Xi2_nomerge_balticsincl,clear

	ren Xi1 lag_Xi2

	ge entry = 1 if Xi2~=. & lag_Xi2==.
	ge exit = 1 if Xi2==. & lag_~=.
	ge continue = 1 if Xi2~=. & lag_~=.

	label var entry "0/1 for Entry"
	label var exit "0/1 for Exit"
	lable var continue "0/1 for Continue"
	
	ge entry_Xi2 = Xi2 if Xi2~=. & lag_Xi2==.
	ge exit_Xi2 = lag_Xi2 if Xi2==. & lag_Xi2~=.
	ge continue_Xi2 = Xi2 if Xi2~=. & lag_Xi2~=.
	
	label var entry_Xi2 "Value for Entry"
	lable var exit_Xi2 "Value for Exit"
	label var continue_Xi2 "Value for Continue"

	collapse (sum) entry* exit* continue*, by(dom time)

	save output/`D'digit_entry_exit_nomerge_balticsincl, replace
	outsheet using output/`D'digit_entry_exit_nomerge_balticsincl.csv, c replace
}
