set more off
set matsize 10000


/*
	Date: September 2016

	Paper: "Income-Induced Expenditure Switching," Bems and di Giovanni (2016)

	Calcultes intensive/extensive margine to plot in Matlab for Figure A2
	
	Program: 
	
		1. Loads in super market data
		2. Calculate intensive/extensive margins
		3. Collapses by domestic and foreign each period
	
*/


/********************************************************
  Function to decompose intensive/extensive 
  margin at any level of aggregation
  Variables:
	`1': "aggregate" id
	`2': date
	`3': revenue
*********************************************************/

capture program drop gr_decomp
program define gr_decomp
	
	* Calculate aggregate growth
	
	sort `1' `2'
	save temp_ag, replace
	collapse (sum) `3' lag_`3', by(`1' `2')
	xtset `1' `2'
	ge gr_T=ln(`3')-ln(lag_`3')
	save grT, replace
	
	* Calculate intensive growth
	 
	use temp_ag, clear
	keep if `3'~=. & lag_`3'~=. & `3'~=0 & lag_`3'~=0
	collapse (sum) `3' lag_`3', by(`1' `2')
	xtset `1' `2'
	ge gr_int=ln(`3')-ln(lag_`3')
	save grI, replace


	* Calculate extensive growth
	
	use grT, clear
	sort `1' `2'
	merge `1' `2' using grI
	drop _m
	sort `1' `2'
	ge gr_ext = gr_T-gr_int
				
	keep `1' `2' gr_*
	xtset `1' `2'
	
	erase grI.dta
	erase grT.dta
	erase temp_ag.dta
end


/********************************
   Overall INT/EXT decomposition
*********************************/

foreach D of numlist 4{
	* Total sales
	
	use 4julian_`D'digit_Xi1Xi2_nomerge_balticsincl,clear
	ge agg = 1
	ren Xi1 lag_Xi2
	
	gr_decomp agg time Xi2 
	save temp, replace
	
	* Foreign sales
	
	use 4julian_`D'digit_Xi1Xi2_nomerge_balticsincl,clear
	ge agg = 1
	ren Xi1 lag_Xi2
	keep if dom==0
	gr_decomp agg time Xi2
	
	foreach X of varlist gr*{
		ren `X' `X'F
	}

	* Calculate growth rates of total, intensive (int) and extensive (ext)
	* magins for expenditure share (ES) 

	sort agg time
	merge agg time using temp
	drop _m
	drop agg
	ge gr_T_ES = gr_TF-gr_T
	ge gr_int_ES = gr_intF-gr_int
	ge gr_ext_ES = gr_extF-gr_ext
	tsset time
	erase temp.dta

	foreach X of varlist gr*ES{
		ge cum_`X' = `X'+l.`X'+l2.`X'+l3.`X'
	}			
	save output/`D'digit_intext_T_nomerge_balticsincl, replace
	outsheet using output/`D'digit_intext_T_nomerge_balticsincl.csv, c replace
}
