set more off
set matsize 10000

capture log close
log using table4, text replace

/*
	Date: September 2016

	Paper: "Income-Induced Expenditure Switching," Bems and di Giovanni (2016)

	Replication of import shares/growth for durables vs. non-durables in Table 4
	
	Program: 
	
		1. Loads 2 digit annual trade data from Eurostat
		2. Merge using concordance defining durable vs. non-durable 
			(e.g., Engel and Wang, 2005)
		3. Tabulate statistics for Latvia
	
*/

local cty LVA

/**************************
  Durable and non-durable
**************************/

* Get data

use `cty'_2digA, clear
egen cc = group(product partner)
xtset cc date
ge lval = l.val
ren product comm2
collapse (sum) val lval, by(comm2 date)
merge comm2 using comm2_durable
tab _m
tab comm if _m==1
tab comm if _m==2
keep if _m==3
collapse (sum) val lval, by(durable date)

* Calculate statistics

egen tval = sum(val), by(date)
egen tlval = sum(lval), by(date)
ge gr_T = ln(tval)-ln(tlval)
label var gr "Growth rate of total imports"
ge gr = ln(val)-ln(lval)
label var gr "Growth rate of durable of non-durable imports"

ge sh = val/tval
label var sh "Share of durable of non-durable"
table date dur if date>2004, c(m gr m gr_T m sh)

log close
